## 0.33.0.3 (2023-01-26)

python-xlib: remove workaround for pytype (#9590)

## 0.33.0.2 (2023-01-16)

`Xlib`: Import `Pattern` from `re`, not `typing` (#9544)

Refs https://github.com/PyCQA/flake8-pyi/pull/324

## 0.33.0.1 (2023-01-03)

Re-enable NQA102 (#9426)

re-enable NQA102

## 0.33.0.0 (2022-12-28)

Bump python-xlib to 0.33 (#9420)

## 0.32.0.1 (2022-12-07)

3rd-party stubtest: run on Python 3.10 (#9342)

## 0.32.0.0 (2022-11-30)

Added complete Xlib stubs (#9279)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

